# coding: utf-8

# flake8: noqa

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.17.0b0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "0.17.0b5"

# import apis into sdk package
from onepanel.core.api.api.auth_service_api import AuthServiceApi
from onepanel.core.api.api.config_service_api import ConfigServiceApi
from onepanel.core.api.api.cron_workflow_service_api import CronWorkflowServiceApi
from onepanel.core.api.api.label_service_api import LabelServiceApi
from onepanel.core.api.api.namespace_service_api import NamespaceServiceApi
from onepanel.core.api.api.secret_service_api import SecretServiceApi
from onepanel.core.api.api.service_service_api import ServiceServiceApi
from onepanel.core.api.api.workflow_service_api import WorkflowServiceApi
from onepanel.core.api.api.workflow_template_service_api import WorkflowTemplateServiceApi
from onepanel.core.api.api.workspace_service_api import WorkspaceServiceApi
from onepanel.core.api.api.workspace_template_service_api import WorkspaceTemplateServiceApi

# import ApiClient
from onepanel.core.api.api_client import ApiClient
from onepanel.core.api.configuration import Configuration
from onepanel.core.api.exceptions import OpenApiException
from onepanel.core.api.exceptions import ApiTypeError
from onepanel.core.api.exceptions import ApiValueError
from onepanel.core.api.exceptions import ApiKeyError
from onepanel.core.api.exceptions import ApiException
# import models into sdk package
from onepanel.core.api.models.add_secret_key_value_response import AddSecretKeyValueResponse
from onepanel.core.api.models.add_workflow_executions_metrics_request import AddWorkflowExecutionsMetricsRequest
from onepanel.core.api.models.archive_workflow_template_response import ArchiveWorkflowTemplateResponse
from onepanel.core.api.models.artifact_response import ArtifactResponse
from onepanel.core.api.models.create_workflow_execution_body import CreateWorkflowExecutionBody
from onepanel.core.api.models.create_workspace_body import CreateWorkspaceBody
from onepanel.core.api.models.cron_workflow import CronWorkflow
from onepanel.core.api.models.cron_workflow_statistics_report import CronWorkflowStatisticsReport
from onepanel.core.api.models.delete_secret_key_response import DeleteSecretKeyResponse
from onepanel.core.api.models.delete_secret_response import DeleteSecretResponse
from onepanel.core.api.models.file import File
from onepanel.core.api.models.get_access_token_request import GetAccessTokenRequest
from onepanel.core.api.models.get_access_token_response import GetAccessTokenResponse
from onepanel.core.api.models.get_config_response import GetConfigResponse
from onepanel.core.api.models.get_labels_response import GetLabelsResponse
from onepanel.core.api.models.get_workflow_execution_metrics_response import GetWorkflowExecutionMetricsResponse
from onepanel.core.api.models.get_workflow_execution_statistics_for_namespace_response import GetWorkflowExecutionStatisticsForNamespaceResponse
from onepanel.core.api.models.get_workspace_statistics_for_namespace_response import GetWorkspaceStatisticsForNamespaceResponse
from onepanel.core.api.models.google_protobuf_any import GoogleProtobufAny
from onepanel.core.api.models.grpc_gateway_runtime_error import GrpcGatewayRuntimeError
from onepanel.core.api.models.grpc_gateway_runtime_stream_error import GrpcGatewayRuntimeStreamError
from onepanel.core.api.models.is_authorized import IsAuthorized
from onepanel.core.api.models.is_authorized_response import IsAuthorizedResponse
from onepanel.core.api.models.is_valid_token_request import IsValidTokenRequest
from onepanel.core.api.models.is_valid_token_response import IsValidTokenResponse
from onepanel.core.api.models.key_value import KeyValue
from onepanel.core.api.models.labels import Labels
from onepanel.core.api.models.list_cron_workflows_response import ListCronWorkflowsResponse
from onepanel.core.api.models.list_files_response import ListFilesResponse
from onepanel.core.api.models.list_namespaces_response import ListNamespacesResponse
from onepanel.core.api.models.list_secrets_response import ListSecretsResponse
from onepanel.core.api.models.list_services_response import ListServicesResponse
from onepanel.core.api.models.list_workflow_executions_response import ListWorkflowExecutionsResponse
from onepanel.core.api.models.list_workflow_template_versions_response import ListWorkflowTemplateVersionsResponse
from onepanel.core.api.models.list_workflow_templates_response import ListWorkflowTemplatesResponse
from onepanel.core.api.models.list_workspace_response import ListWorkspaceResponse
from onepanel.core.api.models.list_workspace_template_versions_response import ListWorkspaceTemplateVersionsResponse
from onepanel.core.api.models.list_workspace_templates_response import ListWorkspaceTemplatesResponse
from onepanel.core.api.models.log_entry import LogEntry
from onepanel.core.api.models.metric import Metric
from onepanel.core.api.models.namespace import Namespace
from onepanel.core.api.models.node_pool import NodePool
from onepanel.core.api.models.node_pool_option import NodePoolOption
from onepanel.core.api.models.parameter import Parameter
from onepanel.core.api.models.parameter_option import ParameterOption
from onepanel.core.api.models.secret import Secret
from onepanel.core.api.models.secret_exists_response import SecretExistsResponse
from onepanel.core.api.models.service import Service
from onepanel.core.api.models.statistics import Statistics
from onepanel.core.api.models.stream_result_of_log_entry import StreamResultOfLogEntry
from onepanel.core.api.models.stream_result_of_workflow_execution import StreamResultOfWorkflowExecution
from onepanel.core.api.models.update_secret_key_value_response import UpdateSecretKeyValueResponse
from onepanel.core.api.models.update_workflow_executions_metrics_request import UpdateWorkflowExecutionsMetricsRequest
from onepanel.core.api.models.update_workspace_body import UpdateWorkspaceBody
from onepanel.core.api.models.workflow_execution import WorkflowExecution
from onepanel.core.api.models.workflow_execution_metadata import WorkflowExecutionMetadata
from onepanel.core.api.models.workflow_execution_statistic_report import WorkflowExecutionStatisticReport
from onepanel.core.api.models.workflow_execution_status import WorkflowExecutionStatus
from onepanel.core.api.models.workflow_executions_metrics_response import WorkflowExecutionsMetricsResponse
from onepanel.core.api.models.workflow_template import WorkflowTemplate
from onepanel.core.api.models.workspace import Workspace
from onepanel.core.api.models.workspace_statistic_report import WorkspaceStatisticReport
from onepanel.core.api.models.workspace_status import WorkspaceStatus
from onepanel.core.api.models.workspace_template import WorkspaceTemplate




# coding: utf-8

"""
    Onepanel

    Onepanel API  # noqa: E501

    The version of the OpenAPI document: 0.15.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import onepanel.core.api
from onepanel.core.api.models.get_config_response import GetConfigResponse  # noqa: E501
from onepanel.core.api.rest import ApiException

class TestGetConfigResponse(unittest.TestCase):
    """GetConfigResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test GetConfigResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = onepanel.core.api.models.get_config_response.GetConfigResponse()  # noqa: E501
        if include_optional :
            return GetConfigResponse(
                api_url = '0', 
                domain = '0', 
                fqdn = '0', 
                node_pool = onepanel.core.api.models.node_pool.NodePool(
                    label = '0', 
                    options = [
                        onepanel.core.api.models.node_pool_option.NodePoolOption(
                            name = '0', 
                            value = '0', )
                        ], )
            )
        else :
            return GetConfigResponse(
        )

    def testGetConfigResponse(self):
        """Test GetConfigResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



import os

from IPython.core.magic import (Magics, magics_class, line_magic)
from IPython.display import IFrame

@magics_class
class IPythonMagics(Magics):

    @line_magic
    def nni_ui(self, line):
        src = '//{uid}--{namespace}.{domain}/nni'.format(
            uid=os.getenv('ONEPANEL_RESOURCE_UID'),
            namespace=os.getenv('ONEPANEL_RESOURCE_NAMESPACE'),
            domain=os.getenv('ONEPANEL_DOMAIN'))
        return IFrame(src=src, width='100%', height='500px')
